@@ -1,10 +1,11 @@
+import sys
 import logging
 
 # Create a custom logger
 logger = logging.getLogger(__name__)
 
 # Create handlers
-handler = logging.StreamHandler()
+handler = logging.StreamHandler(sys.stdout)
 handler.setLevel(logging.INFO)
 
 # Create formatters and add it to handlers
